diff --git a/indra/llcorehttp/_httpoprequest.cpp b/indra/llcorehttp/_httpoprequest.cpp
index 085597e7107c922839e5cd169fc5bd81b8799b32..26f6bb3775db0f450fb70733ad6e14577df01937 100644
--- a/indra/llcorehttp/_httpoprequest.cpp
+++ b/indra/llcorehttp/_httpoprequest.cpp
@@ -533,7 +533,7 @@ HttpStatus HttpOpRequest::prepareRequest(HttpService * service)
 	long follow_redirect(1L);
 	long sslPeerV(0L);
 	long sslHostV(0L);
-    long dnsCacheTimeout(60); // Refetch dns after 60 seconds
+    long dnsCacheTimeout(600); // Refetch dns after 600 seconds
     long nobody(0L);
 
 	if (mReqOptions)
diff --git a/indra/llcorehttp/httpcommon.cpp b/indra/llcorehttp/httpcommon.cpp
index e4828021932fa556b8868c785c9fdaca60771634..e0ca63e1284eb358bc1e2d8c2e533ecf1e997fbb 100644
--- a/indra/llcorehttp/httpcommon.cpp
+++ b/indra/llcorehttp/httpcommon.cpp
@@ -299,7 +299,7 @@ CURL *getCurlTemplateHandle()
             // about 700 or so requests and starts issuing TCP RSTs to
             // new connections.  Reuse the DNS lookups for even a few
             // seconds and no RSTs.
-            result = curl_easy_setopt(curlpTemplateHandle, CURLOPT_DNS_CACHE_TIMEOUT, 60); // Refetch dns after 60 seconds
+            result = curl_easy_setopt(curlpTemplateHandle, CURLOPT_DNS_CACHE_TIMEOUT, 600); // Refetch dns after 600 seconds
             check_curl_code(result, CURLOPT_DNS_CACHE_TIMEOUT);
 
 			result = curl_easy_setopt(curlpTemplateHandle, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_2TLS);